==> patchwork-contrib-0.0.3.tar.gz: patchwork-contrib-0.0.3/patchwork/contrib/fastapi/settings.py <==
# -*- coding: utf-8 -*-
from fastapi import FastAPI
from typing import Dict, Any, Type
from pydantic import BaseModel, root_validator

from patchwork.core.typing import ClassPath

try:
    from tortoise import models
except ImportError:
    is_tortoise_installed = False
else:
    is_tortoise_installed = True

try:
    import starsessions
except ImportError:
    is_starsessions_installed = False
else:
    is_starsessions_installed = True

    class SessionsConfig(BaseModel):
        engine: ClassPath[Type[starsessions.SessionBackend]]
        data: ClassPath[Type[BaseModel]]
        options: Dict = {}
        cookie_name: str = "session_id"
        cookie_secret_key: str
        max_age: int = 14 * 24 * 60 * 60
        same_site: str = "lax"
        https_only: bool = True


class PublisherConfig(BaseModel):
    engine: ClassPath
    options: Dict = {}


class JWTConfig(BaseModel):
    secret: str

    # in seconds
    validity: int


class PatchworkFastAPISettings(BaseModel):

    publisher: PublisherConfig = None

    jwt: JWTConfig = None

    if is_tortoise_installed:
        user_model: ClassPath[Type[models.Model]] = None
    else:
        user_model: Any = None

    if is_starsessions_installed:
        sessions: SessionsConfig = None
    else:
        sessions: Any = None

    @root_validator(pre=True)
    def check_installed_deps(cls, values):
        if 'user_model' in values:
            assert is_tortoise_installed, \
                "can't use `user_model` option without Tortoise ORM installed"
        if 'sessions' in values:
            assert is_starsessions_installed, \
                "can't use `sessions` option without Starsessions installed"

        return values


settings: PatchworkFastAPISettings


def configure(app: FastAPI, api_settings: PatchworkFastAPISettings):
    global settings
    settings = api_settings

    if settings.publisher is not None:
        from patchwork.contrib.fastapi import get_publisher
        publisher = get_publisher()
        app.on_event('startup')(publisher.run())
        app.on_event('shutdown')(publisher.terminate())

    if not is_starsessions_installed:
        return

    session_backend: starsessions.SessionBackend = api_settings.sessions.engine(**settings.sessions.options)

    # hijack session type until it becomes configurable in starsessions
    from .session import Session
    sdt = api_settings.sessions.data.type_
    starsessions.middleware.Session = Session[sdt].concretize(sdt)

    app.add_middleware(starsessions.SessionMiddleware,
                       secret_key=settings.sessions.cookie_secret_key,
                       session_cookie=settings.sessions.cookie_name,
                       max_age=settings.sessions.max_age,
                       same_site=settings.sessions.same_site,
                       https_only=settings.sessions.https_only,
                       backend=session_backend
                       )

==> patchwork-contrib-0.0.4.tar.gz: patchwork-contrib-0.0.4/patchwork/contrib/fastapi/settings.py <==
# -*- coding: utf-8 -*-
from fastapi import FastAPI
from typing import Dict, Any, Type
from pydantic import BaseModel, root_validator

from patchwork.core.typing import ClassPath

try:
    from tortoise import models
except ImportError:
    is_tortoise_installed = False
else:
    is_tortoise_installed = True

try:
    import starsessions
except ImportError:
    is_starsessions_installed = False
else:
    is_starsessions_installed = True

    class SessionsConfig(BaseModel):
        engine: ClassPath[Type[starsessions.SessionBackend]]
        data: ClassPath[Type[BaseModel]]
        options: Dict = {}
        cookie_name: str = "session_id"
        cookie_secret_key: str
        max_age: int = 14 * 24 * 60 * 60
        same_site: str = "lax"
        https_only: bool = True


class PublisherConfig(BaseModel):
    engine: ClassPath
    options: Dict = {}


class JWTConfig(BaseModel):
    secret: str

    # in seconds
    validity: int


class PatchworkFastAPISettings(BaseModel):

    publisher: PublisherConfig = None

    jwt: JWTConfig = None

    if is_tortoise_installed:
        user_model: ClassPath[Type[models.Model]] = None
    else:
        user_model: Any = None

    if is_starsessions_installed:
        sessions: SessionsConfig = None
    else:
        sessions: Any = None

    @root_validator(pre=True)
    def check_installed_deps(cls, values):
        if 'user_model' in values:
            assert is_tortoise_installed, \
                "can't use `user_model` option without Tortoise ORM installed"
        if 'sessions' in values:
            assert is_starsessions_installed, \
                "can't use `sessions` option without Starsessions installed"

        return values


settings: PatchworkFastAPISettings


def register_patchwork(app: FastAPI, api_settings: PatchworkFastAPISettings):
    global settings
    settings = api_settings

    if settings.publisher is not None:
        from patchwork.contrib.fastapi import get_publisher
        publisher = get_publisher()
        app.on_event('startup')(publisher.run)
        app.on_event('shutdown')(publisher.terminate)

    if not is_starsessions_installed:
        return

    session_backend: starsessions.SessionBackend = api_settings.sessions.engine(**settings.sessions.options)

    # hijack session type until it becomes configurable in starsessions
    from .session import Session
    sdt = api_settings.sessions.data.type_
    starsessions.middleware.Session = Session[sdt].concretize(sdt)

    app.add_middleware(starsessions.SessionMiddleware,
                       secret_key=settings.sessions.cookie_secret_key,
                       session_cookie=settings.sessions.cookie_name,
                       max_age=settings.sessions.max_age,
                       same_site=settings.sessions.same_site,
                       https_only=settings.sessions.https_only,
                       backend=session_backend
                       )
